Module: Rack::SimpleAuth
- Defined in:
- lib/rack/simple_auth.rb,
lib/rack/simple_auth/logger.rb,
lib/rack/simple_auth/version.rb,
lib/rack/simple_auth/hmac/config.rb,
lib/rack/simple_auth/hmac/request.rb,
lib/rack/simple_auth/hmac/middleware.rb
Overview
Module which Contains different Authorization / Authentication Classes (HMAC, ..)
Defined Under Namespace
Constant Summary collapse
- VERSION =
Current Gem Version
'1.0.7'
Class Method Summary collapse
-
.root ⇒ String
Method to return Gem Root Dir from everywhere in the gem.
Class Method Details
.root ⇒ String
Method to return Gem Root Dir from everywhere in the gem
21 22 23 |
# File 'lib/rack/simple_auth.rb', line 21 def root ::File.dirname(::File.dirname(::File.('..', __FILE__))) end |